@@ -2,6 +2,7 @@
 Utility for printing the tags in the original hex format.
 """
 
+
 def hex_to_string(x):
     """
     Convert a tag number to it's original hex string.
@@ -13,7 +14,8 @@ def hex_to_string(x):
     left = x[:2]
     right = x[2:]
     num_zeroes = 4 - len(right)
-    return left + ('0'*num_zeroes) + right
+    return left + ("0" * num_zeroes) + right
+
 
 def tag_to_hex_strings(tag):
     """
